# $Id: RAA.pm 2144 2009-07-27 20:48:05Z guillomovitch $
package Youri::Check::Test::Updates::Source::RAA;

=head1 NAME

Youri::Check::Test::Updates::Source::RAA - RAA updates source

=head1 DESCRIPTION

This source plugin for L<Youri::Check::Test::Updates> collects updates
available from RAA.

=cut

use warnings;
use strict;
use Carp;
use LWP::UserAgent;
use HTML::TableExtract;
use base 'Youri::Check::Test::Updates::Source';

=head2 new(%args)

Creates and returns a new Youri::Check::Test::Updates::Source::RAA object.

Specific parameters:

=over

=item url $url

URL to RAA index page (default:
http://raa.ruby-lang.org/all.html)

=back

=cut

sub _init {
    my $self    = shift;
    my %options = (
        url => 'http://raa.ruby-lang.org/all.html',
        @_
    );

    my $agent = LWP::UserAgent->new();
    my $response = $agent->get($options{url});
    if ($response->is_success()) {
        my $parser = HTML::TableExtract->new(debug => 1);
        $parser->parse($response->content());
        my $table = $parser->first_table_found();
        foreach my $row ($table->rows()) {
            my $name = $row->[0];
            my $version = $row->[4];
            $name =~ s/\s*$//;
            $version =~ s/\s*$//;
            $self->{_versions}->{$name} = $version;
        }
        delete $self->{_versions}->{Name};
    }
}

sub _url {
    my ($self, $name) = @_;
    return "http://raa.ruby-lang.org/project/$name/";
}

sub _name {
    my ($self, $name) = @_;
    return $name;
}

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2002-2006, YOURI project

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=cut

1;
